Search and create BibLaTeX entries for crates hosted on crates.io or retrieve them from their github repository.
This crate can be used in a web version under jonaspleyer.github.io/crate2bib.
Structs
- BibLa
TeXCratesIO - A fully specified BibLaTeX entry generated from a crate hostedn on crates.io
- NotFound
Error - Envoked if a certain file or entity can not be found which should be there.
- Plain
BibLa TeX - The result of parsing a bibliography file
Enums
- BibLa
TeX - Contains all variants of how a bib entry can be obtained
- Err
- Contains all errors of this crate
Functions
- generate_
biblatex_ crates_ io - Returns a BibLaTeXCratesIO entry for the searched crate.
- get_
biblatex - Obtain multiple BibLaTeX entries from various sources such as crates.io, github and doi.org
- get_
bibtex_ doi - Tries to obtain a bibtex entry from a given DOI
- github_
search_ files - Searches the repository at github.com for citation files
Type Aliases
- Result
- Type-alias for the std::result::Result type with custom Err type.